@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::BagComparison;
 
-our $VERSION = 0.003; # VERSION
+our $VERSION = 0.004; # VERSION
 
 our $results = [
   [
@@ -9,27 +9,27 @@ our $results = [
     [
       {
         dataset    => "elems=200num",
-        errors     => 0.00012,
+        errors     => 0.00013,
         rate       => 11,
-        samples    => 20,
-        time       => 90,
+        samples    => 21,
+        time       => 89,
         vs_slowest => 1,
       },
       {
         dataset    => "elems=100num",
-        errors     => 0.00018,
+        errors     => 4.2e-05,
         rate       => 25,
-        samples    => 21,
-        time       => 40,
-        vs_slowest => 2.2,
+        samples    => 20,
+        time       => 39,
+        vs_slowest => 2.3,
       },
       {
         dataset    => "elems=10num",
-        errors     => 4.2e-07,
-        rate       => 2500,
-        samples    => 21,
-        time       => 0.41,
-        vs_slowest => 220,
+        errors     => 3.9e-07,
+        rate       => 2420,
+        samples    => 24,
+        time       => 0.414,
+        vs_slowest => 216,
       },
     ],
     {
@@ -152,7 +152,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2599.953,
+                                              speed                        => 2777.523,
                                               stepping                     => 4,
                                             },
                                             {
@@ -267,7 +267,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => "2861.250",
+                                              speed                        => 2872.132,
                                               stepping                     => 4,
                                             },
                                             {
@@ -382,7 +382,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2600.007,
+                                              speed                        => "2871.640",
                                               stepping                     => 4,
                                             },
                                             {
@@ -497,13 +497,14 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2795.898,
+                                              speed                        => 2834.289,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 3.36738705635071,
+      "func.elapsed_time"              => 3.43977093696594,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
+                                            "__PACKAGE__" => 1.034,
                                             "Bencher::Scenario::BagComparison" => undef,
                                             "Benchmark::Dumb" => "0.10",
                                             "Devel::Platform::Info" => 0.16,
@@ -542,9 +543,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1476882432,
       "func.scenario_module_sha1sum"   => "1b5be441bfbe5a0322ebf80c7eb8dd8c6fca6f77",
       "func.scenario_module_sha256sum" => "3cb78f801e94a7c4fbeb7693fab11a484812ec522b46359515e069c45f789ab6",
-      "func.time_end"                  => 1485312945.28562,
+      "func.time_end"                  => 1485317294.41088,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1485312941.91824,
+      "func.time_start"                => 1485317290.97111,
       "table.field_aligns"             => ["left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, "/s", "ms"],
       "table.fields"                   => ["dataset", "rate", "time", "vs_slowest", "errors", "samples"],
